@@ -5,11 +5,18 @@
 adjustOptions <- function(availableOptions, optionsToSet){
   
   namesAvailableOptions <- names(availableOptions)
-  changeOptions <- namesAvailableOptions[namesAvailableOptions %in% names(optionsToSet)]
+  namesOptionsToSet <- names(optionsToSet)
+  changeOptions <- namesAvailableOptions[namesAvailableOptions %in% namesOptionsToSet]
   if(length(changeOptions)>0){
     for (option in changeOptions) 
       availableOptions[[option]] <- optionsToSet[[option]]
   }
   
+  additionalOptions <- namesOptionsToSet[!is.element(namesOptionsToSet, namesAvailableOptions)]
+  if(length(additionalOptions)>0){
+    for (option in additionalOptions) 
+      availableOptions[[option]] <- optionsToSet[[option]]
+  }
+  
   availableOptions
 }
\ No newline at end of file
