@@ -6,7 +6,8 @@ runGIES <- function(X, interventions, parentsOf, variableSelMat, setOptions,
     stop("'interventions' cannot be 'NULL' for method 'gies'")
   
   # additional optionsList for GIES
-  optionsList <- list("phase"="turning", "maxDegree"=integer(0), 
+  optionsList <- list("phase"=c("forward", "backward", "turning"), 
+                      "maxDegree"=integer(0), 
                       "lambda" = 0.5*log(nrow(X)))
   
   # adjust according to setOptions if necessary
@@ -33,7 +34,8 @@ runGIES <- function(X, interventions, parentsOf, variableSelMat, setOptions,
 
   tmp <- pcalg::gies(score, 
                      fixedGaps=if(is.null(variableSelMat)) NULL else (!variableSelMat), 
-                     phase=optionsList$phase, maxDegree=optionsList$maxDegree,
+                     phase=optionsList$phase, 
+                     maxDegree=optionsList$maxDegree,
                      verbose=verbose, ...)
    
   giesmat <- as(tmp$essgraph, "matrix")
